# whichtok
by Sarah Chen

## Why Whichtok?
Whichtok constructs graphs out of TikTok content. 

## Getting Started
Dependencies:
```
pip install TikTokApi
```
Whichtok uses [`TikTok-Api`](https://davidteather.github.io/TikTok-Api/) to scrape video and user data from TikTok
